@@ -19,10 +19,11 @@
  */
 
 #include "application-tile.h"
+#include "config.h"
 
 #include <string.h>
-#include <glib/gi18n.h>
-#include <glib/gfileutils.h>
+#include <glib.h>
+#include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
 #include <gconf/gconf-client.h>
 #include <unistd.h>
@@ -303,6 +304,7 @@ application_tile_setup (ApplicationTile *this, const gchar *gconf_prefix)
 
 	const gchar *key;
 	gchar *markup;
+	gchar *str;
 
 	/*Fixme - need to address the entire gconf key location issue */
 	/*Fixme - this is just a temporary stop gap                   */
@@ -345,12 +347,12 @@ application_tile_setup (ApplicationTile *this, const gchar *gconf_prefix)
 		"nameplate-image",         image,
 		"nameplate-header",        header,
 		"nameplate-subheader",     subheader,
-		"nameplate-tooltip",	   comment,
 		"context-menu",            context_menu,
 		"application-name",        name,
 		"application-description", desc,
 		"gconf-prefix",            gconf_prefix,
 		NULL);
+	gtk_widget_set_tooltip_text (GTK_WIDGET (this), comment);
 
 	priv->agent = bookmark_agent_get_instance (BOOKMARK_STORE_USER_APPS);
 	g_object_get (G_OBJECT (priv->agent), BOOKMARK_AGENT_STORE_STATUS_PROP, & priv->agent_status, NULL);
@@ -369,10 +371,12 @@ application_tile_setup (ApplicationTile *this, const gchar *gconf_prefix)
 
 /* make start action */
 
-	markup = g_markup_printf_escaped (_("<b>Start %s</b>"), this->name);
+	str = g_strdup_printf (_("Start %s"), this->name);
+	markup = g_markup_printf_escaped ("<b>%s</b>", str);
 	action = tile_action_new (TILE (this), start_trigger, markup, TILE_ACTION_OPENS_NEW_WINDOW);
 	actions [APPLICATION_TILE_ACTION_START] = action;
 	g_free (markup);
+	g_free (str);
 
 	menu_item = GTK_WIDGET (tile_action_get_menu_item (action));
 
